"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLocalIdentGetter = void 0;
const path = require("path");
const idgen_1 = require("./idgen");
const DEFAULT_ALPHABET = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890';
function createLocalIdentGetter(opt = {}) {
    if (opt.bypass)
        return undefined;
    const resourceIdGen = idgen_1.idgen(opt.alphabet ?? DEFAULT_ALPHABET);
    const resources = new Map();
    function getShortIdent(resourcePath, localName) {
        let resource = resources.get(resourcePath);
        if (!resource) {
            resource = {
                id: resourceIdGen(),
                localIdGen: idgen_1.idgen(opt.alphabet ?? DEFAULT_ALPHABET),
                locals: new Map(),
            };
            resources.set(resourcePath, resource);
        }
        let local = resource.locals.get(localName);
        if (!local) {
            local = resource.localIdGen();
            resource.locals.set(localName, local);
        }
        return `${opt.prefix}${resource.id}_${local}${opt.suffix}`;
    }
    return (context, localIdentName, localName, _options) => {
        const relPath = path
            .relative(context.rootContext, context.resourcePath)
            // windows paths fix
            .replace(/\\/g, '/');
        return getShortIdent(relPath, localName);
    };
}
exports.createLocalIdentGetter = createLocalIdentGetter;
//# sourceMappingURL=index.js.map